@@ -1,5 +1,5 @@
 /* callback.c --- Callback handling.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -13,9 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
- * License along with GNU SASL Library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License License along with GNU SASL Library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -151,10 +152,10 @@ gsasl_callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
 	if (!cb_retrieve)
 	  break;
 	res = cb_retrieve (sctx, sctx->authid, sctx->authzid,
-			   sctx->hostname, &buf, &buflen);
+			   sctx->hostname, buf, &buflen);
 	if (res == GSASL_OK)
 	  gsasl_property_set_raw (sctx, GSASL_PASSWORD, buf, buflen);
-	/* FIXME else if (res == GSASL_TOO_SMALL_BUFFER)...*/
+	/* FIXME else if (res == GSASL_TOO_SMALL_BUFFER)... */
 	return res;
 	break;
 
