@@ -50,7 +50,7 @@ const char *GSASL_VALID_MECHANISM_CHARACTERS =
 static int
 register_builtin_mechs (Gsasl * ctx)
 {
-  int rc;
+  int rc = GSASL_OK;
 
 #ifdef USE_ANONYMOUS
   rc = gsasl_register (ctx, &gsasl_anonymous_mechanism);
@@ -64,18 +64,18 @@ register_builtin_mechs (Gsasl * ctx)
     return rc;
 #endif /* USE_EXTERNAL */
 
-#ifdef USE_PLAIN
-  rc = gsasl_register (ctx, &gsasl_plain_mechanism);
-  if (rc != GSASL_OK)
-    return rc;
-#endif /* USE_PLAIN */
-
 #ifdef USE_LOGIN
   rc = gsasl_register (ctx, &gsasl_login_mechanism);
   if (rc != GSASL_OK)
     return rc;
 #endif /* USE_LOGIN */
 
+#ifdef USE_PLAIN
+  rc = gsasl_register (ctx, &gsasl_plain_mechanism);
+  if (rc != GSASL_OK)
+    return rc;
+#endif /* USE_PLAIN */
+
 #ifdef USE_SECURID
   rc = gsasl_register (ctx, &gsasl_securid_mechanism);
   if (rc != GSASL_OK)
@@ -123,7 +123,6 @@ register_builtin_mechs (Gsasl * ctx)
 int
 gsasl_init (Gsasl ** ctx)
 {
-  size_t i;
   int rc;
 
   if (gc_init () != GC_OK)
