@@ -1,5 +1,5 @@
 /* gsasl.c --- Command line interface to libgsasl.
- * Copyright (C) 2002, 2003, 2004, 2005  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2005, 2006  Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -24,6 +24,10 @@
 #include "imap.h"
 #include "smtp.h"
 
+#ifdef HAVE_WS2TCPIP_H
+# include <ws2tcpip.h>
+#endif
+
 #ifdef HAVE_LIBGNUTLS
 # include <gnutls/gnutls.h>
 gnutls_session session;
@@ -276,6 +280,19 @@ main (int argc, char *argv[])
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 
+#ifdef HAVE_WS2TCPIP_H
+  {
+    WORD wVersionRequested;
+    WSADATA wsaData;
+    int r;
+
+    wVersionRequested = MAKEWORD(2, 0);
+    r = WSAStartup( wVersionRequested, &wsaData);
+    if (r)
+      error (EXIT_FAILURE, 0, _("Cannot initialize Windows sockets."));
+  }
+#endif
+
   if (cmdline_parser (argc, argv, &args_info) != 0)
     return 1;
 
